@@ -45,10 +45,12 @@ async def create_evaluators(evaluator_parent_class,
                             matrix_id: str,
                             exchange_name: str,
                             bot_id: str,
-                            symbols_by_crypto_currencies: dict = None,
+                            crypto_currency_name_by_crypto_currencies: dict,
+                            symbols_by_crypto_currency_tickers: dict,
                             symbols: list = None,
                             time_frames: list = None,
-                            relevant_evaluators=CONFIG_WILDCARD) -> list:
+                            real_time_time_frames: list = None,
+                            relevant_evaluators=CONFIG_WILDCARD,) -> list:
     return [
         await create_evaluator(evaluator_class,
                                tentacles_setup_config,
@@ -56,19 +58,34 @@ async def create_evaluators(evaluator_parent_class,
                                exchange_name=exchange_name,
                                bot_id=bot_id,
                                cryptocurrency=cryptocurrency,
+                               cryptocurrency_name=_get_cryptocurrency_name(
+                                   evaluator_class,
+                                   crypto_currency_name_by_crypto_currencies,
+                                   cryptocurrency),
                                symbol=symbol,
                                time_frame=time_frame,
-                               relevant_evaluators=relevant_evaluators
+                               relevant_evaluators=relevant_evaluators,
+                               all_symbols_by_crypto_currencies=symbols_by_crypto_currency_tickers,
+                               time_frames=time_frames,
+                               real_time_time_frames=real_time_time_frames
                                )
         for evaluator_class in create_advanced_types_list(evaluator_parent_class, config)
-        for cryptocurrency in _get_cryptocurrencies_to_create(evaluator_class, symbols_by_crypto_currencies.keys())
-        for symbol in _get_symbols_to_create(evaluator_class, symbols_by_crypto_currencies, cryptocurrency, symbols)
+        for cryptocurrency in _get_cryptocurrencies_to_create(evaluator_class,
+                                                              crypto_currency_name_by_crypto_currencies)
+        for symbol in _get_symbols_to_create(evaluator_class, symbols_by_crypto_currency_tickers,
+                                             cryptocurrency, symbols)
         for time_frame in _get_time_frames_to_create(evaluator_class, time_frames)
     ]
 
 
-def _get_cryptocurrencies_to_create(evaluator_class, cryptocurrencies):  # TODO replace with python 3.8 by :=
-    return cryptocurrencies if cryptocurrencies and not evaluator_class.get_is_cryptocurrencies_wildcard() else [None]
+def _get_cryptocurrency_name(evaluator_class, crypto_currency_name_by_crypto_currencies, cryptocurrency):
+    return crypto_currency_name_by_crypto_currencies[cryptocurrency] if crypto_currency_name_by_crypto_currencies \
+        and cryptocurrency is not None and not evaluator_class.get_is_cryptocurrency_name_wildcard() else None
+
+
+def _get_cryptocurrencies_to_create(evaluator_class, crypto_currency_name_by_crypto_currencies):
+    return crypto_currency_name_by_crypto_currencies.keys() if crypto_currency_name_by_crypto_currencies \
+        and not evaluator_class.get_is_cryptocurrencies_wildcard() else [None]
 
 
 def _get_symbols_to_create(evaluator_class, symbols_by_crypto_currencies, cryptocurrency,
@@ -92,12 +109,12 @@ async def stop_evaluator_channel(matrix_id, chan_name) -> None:
     try:
         await get_chan(chan_name, matrix_id).stop()
     except Exception as e:
-        get_logger().exception(e, True, f"Error when stopping evaluator channel {chan_name}: {e}")
+        get_logger("EvaluatorsAPI").exception(e, True, f"Error when stopping evaluator channel {chan_name}: {e}")
 
 
 async def stop_all_evaluator_channels(matrix_id) -> None:
     for channel in ChannelInstances.instance().channels[matrix_id]:
-        await stop_evaluator_channel(matrix_id, channel.get_name())
+        await stop_evaluator_channel(matrix_id, channel)
 
 
 def get_evaluator_classes_from_type(evaluator_type, config, tentacles_setup_config, activated_only=True) -> list:
@@ -113,9 +130,13 @@ async def create_evaluator(evaluator_class,
                            exchange_name: str,
                            bot_id: str,
                            cryptocurrency: str = None,
+                           cryptocurrency_name: str = None,
                            symbol: str = None,
                            time_frame=None,
-                           relevant_evaluators=CONFIG_WILDCARD):
+                           relevant_evaluators=CONFIG_WILDCARD,
+                           all_symbols_by_crypto_currencies=None,
+                           time_frames=None,
+                           real_time_time_frames=None):
     try:
         eval_class_instance = evaluator_class()
         eval_class_instance.set_tentacles_setup_config(tentacles_setup_config)
@@ -123,28 +144,28 @@ async def create_evaluator(evaluator_class,
             eval_class_instance.logger = get_logger(evaluator_class.get_name())
             eval_class_instance.matrix_id = matrix_id
             eval_class_instance.exchange_name = exchange_name if exchange_name else None
-            eval_class_instance.cryptocurrency = cryptocurrency if cryptocurrency else None
+            eval_class_instance.cryptocurrency = cryptocurrency
+            eval_class_instance.cryptocurrency_name = cryptocurrency_name
             eval_class_instance.symbol = symbol if symbol else None
             eval_class_instance.time_frame = time_frame if time_frame else eval_class_instance.time_frame
             eval_class_instance.evaluator_type = evaluator_class_str_to_matrix_type_dict[
                 eval_class_instance.__class__.mro()[EVALUATOR_CLASS_TYPE_MRO_INDEX].__name__]
-            eval_class_instance.initialize()
+            eval_class_instance.initialize(all_symbols_by_crypto_currencies, time_frames, real_time_time_frames)
             await eval_class_instance.prepare()
             # handle backtesting
             await eval_class_instance.start_evaluator(bot_id)
             return eval_class_instance
     except Exception as e:
-        get_logger().exception(e, True, f"Error when creating evaluator {evaluator_class}: {e}")
+        get_logger("EvaluatorsAPI").exception(e, True, f"Error when creating evaluator {evaluator_class}: {e}")
     return None
 
 
-"""
-:param config: evaluator config
-:return: initialized matrix id
-"""
-
-
 async def initialize_evaluators(config, tentacles_setup_config) -> str:
+    """
+    :param config: bot config
+    :param tentacles_setup_config: tentacles configuration
+    :return: initialized matrix id
+    """
     create_evaluator_classes(config)
     _init_time_frames(config, tentacles_setup_config)
 
@@ -189,12 +210,31 @@ async def create_all_type_evaluators(config: dict,
                                      symbols_by_crypto_currencies: dict = None,
                                      symbols: list = None,
                                      time_frames: list = None,
+                                     real_time_time_frames: list = None,
                                      relevant_evaluators=CONFIG_WILDCARD,
                                      ) -> list:
-    return [await create_evaluators(evaluator_type, config, tentacles_setup_config,
-                                    matrix_id=matrix_id, exchange_name=exchange_name,
-                                    bot_id=bot_id,
-                                    symbols=symbols, time_frames=time_frames,
-                                    symbols_by_crypto_currencies=symbols_by_crypto_currencies,
-                                    relevant_evaluators=relevant_evaluators)
+    crypto_currency_name_by_crypto_currencies = {}
+    symbols_by_crypto_currency_tickers = {}
+    try:
+        from octobot_trading.api.exchange import get_exchange_manager_from_exchange_name_and_id, \
+            get_exchange_id_from_matrix_id, get_base_currency
+        exchange_id = get_exchange_id_from_matrix_id(exchange_name, matrix_id)
+        exchange_manager = get_exchange_manager_from_exchange_name_and_id(exchange_name, exchange_id)
+        for name, symbol_list in symbols_by_crypto_currencies.items():
+            if symbol_list:
+                ticker = get_base_currency(exchange_manager, symbol_list[0])
+                crypto_currency_name_by_crypto_currencies[ticker] = name
+                symbols_by_crypto_currency_tickers[ticker] = symbol_list
+        return [
+            await create_evaluators(
+                evaluator_type, config, tentacles_setup_config,
+                matrix_id=matrix_id, exchange_name=exchange_name,
+                bot_id=bot_id,
+                crypto_currency_name_by_crypto_currencies=crypto_currency_name_by_crypto_currencies,
+                symbols_by_crypto_currency_tickers=symbols_by_crypto_currency_tickers,
+                symbols=symbols, time_frames=time_frames,
+                real_time_time_frames=real_time_time_frames,
+                relevant_evaluators=relevant_evaluators)
             for evaluator_type in EvaluatorClassTypes.values()]
+    except ImportError:
+        get_logger("EvaluatorsAPI").error("create_evaluators requires Octobot-Trading package installed")
